function [error stdev] = plsa_class(A, g, t, nfold)

%Gene selection by variance
G = genesel_var(A, g);
%Scaling in order to have integer and positive values
data = G.data - min(G.data(:));
data = data./max(data(:));
data = round(1000*data);
G_PLSA = prdataset(data, A.nlab);
clear data
data = G_PLSA.data;

%Set up nfold crossvalidation
R = prcrossval(G_PLSA, [], nfold, 0);
plsa_reps = 10;

for reps=1:plsa_reps
    %Learning phase
    [wt, td, E] = plsa(data', t, 0.000001, 0);
    savedE(reps) = mean(E);
    savedtd{reps} = td;
end
%Select the best model (in a likelihood sense) over the repetitions
[val, bestPLSAlearning] = max(savedE);
td = savedtd{bestPLSAlearning};
dataset_plsa = prdataset(td', G_PLSA.nlab);

for r=1:nfold
    %subdivision train:test
    data_train = dataset_plsa.data((R~=r), :)';
    data_test = dataset_plsa.data((R==r), :)';
    labels_train = dataset_plsa.nlab(R~=r);
    labels_test = dataset_plsa.nlab(R==r);
    %classification
    error(r,:) = plsa_classify_itkernels(data_train, labels_train,data_test, labels_test);
end

error = mean(error);
stdev = std(error);

end